@@ -1,8 +1,8 @@
-# This code is part of Perl distribution OODoc version 3.05.
-# The POD got stripped from this file by OODoc version 3.05.
+# This code is part of Perl distribution OODoc version 3.06.
+# The POD got stripped from this file by OODoc version 3.06.
 # For contributors see file ChangeLog.
 
-# This software is copyright (c) 2003-2025 by Mark Overmeer.
+# This software is copyright (c) 2003-2026 by Mark Overmeer.
 
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
@@ -10,7 +10,7 @@
 
 
 package OODoc::Parser::Markov;{
-our $VERSION = '3.05';
+our $VERSION = '3.06';
 }
 
 use parent 'OODoc::Parser';
@@ -799,7 +799,7 @@ sub cleanupHtml($$$)
 	{	unless($is_html)
 		{	s#\&#\&amp;#g;
 			s#(\s|^) \< ([^<>]+) \> #$1&lt;$2&gt;#gx;
-#			s#(?<!\b[BCEFILSXMP<])\<#&lt;#g;
+			s#(?<!\b[BCEFILSXMP<])\<#&lt;#g;
 			s#([=-])\>#$1\&gt;#g;
 		}
 		s# ([A-Z]) (?: \<\<\s*(.*?)\s*\>\> | \<(.*?)\> ) # $self->_htmlReformat($manual, $1, $+, \%args) #gxe;
